@@ -1,6 +1,6 @@
 package File::Dedup;
 # ABSTRACT: Deduplicate files across directories
-$File::Dedup::VERSION = '0.001';
+$File::Dedup::VERSION = '0.002';
 use strict;
 use warnings;
 
@@ -184,8 +184,7 @@ sub _prompt {
 
 sub _dirwalk {
    my ($self, $top, $filefunc, $dirfunc) = @_;
-   use Data::Dumper;
-   print Dumper $top;
+
    if ( -d $top ) {
       # stop processing non-recursive searches when a directory that
       # was not the starting directory is encountered
@@ -224,7 +223,7 @@ File::Dedup - Deduplicate files across directories
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -249,6 +248,26 @@ A small utility to identify duplicate files in a given directory and optionally
 
 File::Dedup
 
+=head1 ATTRIBUTES 
+
+=over 4 
+
+=item C<directory>
+
+Directory to start searching for duplicates in. [required]
+
+=item C<ask>
+
+=item C<recursive>
+
+Recursively search the directory tree for duplicates. [optional]
+
+=item C<group>
+
+*NOT YET IMPLEMENTED*. Instead of deleting duplicates this option will write all duplicates into their own subfolders for deletion at the user's leisure.
+
+=back
+
 =head1 METHODS
 
 =over 4
